# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
GeomEvaluator module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_geomevaluator.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _GeomEvaluator
else:
    import _GeomEvaluator

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _GeomEvaluator.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _GeomEvaluator.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _GeomEvaluator.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _GeomEvaluator.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _GeomEvaluator.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _GeomEvaluator.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _GeomEvaluator.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _GeomEvaluator.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _GeomEvaluator.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _GeomEvaluator.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _GeomEvaluator.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _GeomEvaluator.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _GeomEvaluator.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _GeomEvaluator.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _GeomEvaluator.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _GeomEvaluator.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _GeomEvaluator.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _GeomEvaluator:
_GeomEvaluator.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _GeomEvaluator.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.GeomAdaptor
import OCC.Core.Adaptor3d
import OCC.Core.TopAbs
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.math
import OCC.Core.Message
import OCC.Core.OSD

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_GeomEvaluator_Curve_Create() -> "opencascade::handle< GeomEvaluator_Curve >":
    return _GeomEvaluator.Handle_GeomEvaluator_Curve_Create()

def Handle_GeomEvaluator_Curve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< GeomEvaluator_Curve >":
    return _GeomEvaluator.Handle_GeomEvaluator_Curve_DownCast(t)

def Handle_GeomEvaluator_Curve_IsNull(t: "opencascade::handle< GeomEvaluator_Curve > const &") -> "bool":
    return _GeomEvaluator.Handle_GeomEvaluator_Curve_IsNull(t)

def Handle_GeomEvaluator_Surface_Create() -> "opencascade::handle< GeomEvaluator_Surface >":
    return _GeomEvaluator.Handle_GeomEvaluator_Surface_Create()

def Handle_GeomEvaluator_Surface_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< GeomEvaluator_Surface >":
    return _GeomEvaluator.Handle_GeomEvaluator_Surface_DownCast(t)

def Handle_GeomEvaluator_Surface_IsNull(t: "opencascade::handle< GeomEvaluator_Surface > const &") -> "bool":
    return _GeomEvaluator.Handle_GeomEvaluator_Surface_IsNull(t)

def Handle_GeomEvaluator_OffsetCurve_Create() -> "opencascade::handle< GeomEvaluator_OffsetCurve >":
    return _GeomEvaluator.Handle_GeomEvaluator_OffsetCurve_Create()

def Handle_GeomEvaluator_OffsetCurve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< GeomEvaluator_OffsetCurve >":
    return _GeomEvaluator.Handle_GeomEvaluator_OffsetCurve_DownCast(t)

def Handle_GeomEvaluator_OffsetCurve_IsNull(t: "opencascade::handle< GeomEvaluator_OffsetCurve > const &") -> "bool":
    return _GeomEvaluator.Handle_GeomEvaluator_OffsetCurve_IsNull(t)

def Handle_GeomEvaluator_OffsetSurface_Create() -> "opencascade::handle< GeomEvaluator_OffsetSurface >":
    return _GeomEvaluator.Handle_GeomEvaluator_OffsetSurface_Create()

def Handle_GeomEvaluator_OffsetSurface_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< GeomEvaluator_OffsetSurface >":
    return _GeomEvaluator.Handle_GeomEvaluator_OffsetSurface_DownCast(t)

def Handle_GeomEvaluator_OffsetSurface_IsNull(t: "opencascade::handle< GeomEvaluator_OffsetSurface > const &") -> "bool":
    return _GeomEvaluator.Handle_GeomEvaluator_OffsetSurface_IsNull(t)

def Handle_GeomEvaluator_SurfaceOfExtrusion_Create() -> "opencascade::handle< GeomEvaluator_SurfaceOfExtrusion >":
    return _GeomEvaluator.Handle_GeomEvaluator_SurfaceOfExtrusion_Create()

def Handle_GeomEvaluator_SurfaceOfExtrusion_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< GeomEvaluator_SurfaceOfExtrusion >":
    return _GeomEvaluator.Handle_GeomEvaluator_SurfaceOfExtrusion_DownCast(t)

def Handle_GeomEvaluator_SurfaceOfExtrusion_IsNull(t: "opencascade::handle< GeomEvaluator_SurfaceOfExtrusion > const &") -> "bool":
    return _GeomEvaluator.Handle_GeomEvaluator_SurfaceOfExtrusion_IsNull(t)

def Handle_GeomEvaluator_SurfaceOfRevolution_Create() -> "opencascade::handle< GeomEvaluator_SurfaceOfRevolution >":
    return _GeomEvaluator.Handle_GeomEvaluator_SurfaceOfRevolution_Create()

def Handle_GeomEvaluator_SurfaceOfRevolution_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< GeomEvaluator_SurfaceOfRevolution >":
    return _GeomEvaluator.Handle_GeomEvaluator_SurfaceOfRevolution_DownCast(t)

def Handle_GeomEvaluator_SurfaceOfRevolution_IsNull(t: "opencascade::handle< GeomEvaluator_SurfaceOfRevolution > const &") -> "bool":
    return _GeomEvaluator.Handle_GeomEvaluator_SurfaceOfRevolution_IsNull(t)
class GeomEvaluator_Curve(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def D0(self, *args) -> "void":
        r"""
        Value of 3d curve.

        Parameters
        ----------
        theU: float
        theValue: gp_Pnt

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_Curve_D0(self, *args)

    def D1(self, *args) -> "void":
        r"""
        Value and first derivatives of curve.

        Parameters
        ----------
        theU: float
        theValue: gp_Pnt
        theD1: gp_Vec

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_Curve_D1(self, *args)

    def D2(self, *args) -> "void":
        r"""
        Value, first and second derivatives of curve.

        Parameters
        ----------
        theU: float
        theValue: gp_Pnt
        theD1: gp_Vec
        theD2: gp_Vec

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_Curve_D2(self, *args)

    def D3(self, *args) -> "void":
        r"""
        Value, first, second and third derivatives of curve.

        Parameters
        ----------
        theU: float
        theValue: gp_Pnt
        theD1: gp_Vec
        theD2: gp_Vec
        theD3: gp_Vec

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_Curve_D3(self, *args)

    def DN(self, *args) -> "gp_Vec":
        r"""
        Calculates n-th derivatives of curve, where n = thederu. raises if n < 1.

        Parameters
        ----------
        theU: float
        theDerU: int

        Returns
        -------
        gp_Vec

        """
        return _GeomEvaluator.GeomEvaluator_Curve_DN(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_GeomEvaluator_Curve_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _GeomEvaluator.delete_GeomEvaluator_Curve

# Register GeomEvaluator_Curve in _GeomEvaluator:
_GeomEvaluator.GeomEvaluator_Curve_swigregister(GeomEvaluator_Curve)

class GeomEvaluator_Surface(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def D0(self, *args) -> "void":
        r"""
        Value of surface.

        Parameters
        ----------
        theU: float
        theV: float
        theValue: gp_Pnt

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_Surface_D0(self, *args)

    def D1(self, *args) -> "void":
        r"""
        Value and first derivatives of surface.

        Parameters
        ----------
        theU: float
        theV: float
        theValue: gp_Pnt
        theD1U: gp_Vec
        theD1V: gp_Vec

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_Surface_D1(self, *args)

    def D2(self, *args) -> "void":
        r"""
        Value, first and second derivatives of surface.

        Parameters
        ----------
        theU: float
        theV: float
        theValue: gp_Pnt
        theD1U: gp_Vec
        theD1V: gp_Vec
        theD2U: gp_Vec
        theD2V: gp_Vec
        theD2UV: gp_Vec

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_Surface_D2(self, *args)

    def D3(self, *args) -> "void":
        r"""
        Value, first, second and third derivatives of surface.

        Parameters
        ----------
        theU: float
        theV: float
        theValue: gp_Pnt
        theD1U: gp_Vec
        theD1V: gp_Vec
        theD2U: gp_Vec
        theD2V: gp_Vec
        theD2UV: gp_Vec
        theD3U: gp_Vec
        theD3V: gp_Vec
        theD3UUV: gp_Vec
        theD3UVV: gp_Vec

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_Surface_D3(self, *args)

    def DN(self, *args) -> "gp_Vec":
        r"""
        Calculates n-th derivatives of surface, where n = thederu + thederv. //! raises if n < 1 or thederu < 0 or thederv < 0.

        Parameters
        ----------
        theU: float
        theV: float
        theDerU: int
        theDerV: int

        Returns
        -------
        gp_Vec

        """
        return _GeomEvaluator.GeomEvaluator_Surface_DN(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_GeomEvaluator_Surface_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _GeomEvaluator.delete_GeomEvaluator_Surface

# Register GeomEvaluator_Surface in _GeomEvaluator:
_GeomEvaluator.GeomEvaluator_Surface_swigregister(GeomEvaluator_Surface)

class GeomEvaluator_OffsetCurve(GeomEvaluator_Curve):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initialize evaluator by curve.

        Parameters
        ----------
        theBase: Geom_Curve
        theOffset: float
        theDirection: gp_Dir

        Returns
        -------
        None
        Initialize evaluator by curve adaptor.

        Parameters
        ----------
        theBase: GeomAdaptor_HCurve
        theOffset: float
        theDirection: gp_Dir

        Returns
        -------
        None

        """
        _GeomEvaluator.GeomEvaluator_OffsetCurve_swiginit(self, _GeomEvaluator.new_GeomEvaluator_OffsetCurve(*args))

    def SetOffsetDirection(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theDirection: gp_Dir

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_OffsetCurve_SetOffsetDirection(self, *args)

    def SetOffsetValue(self, *args) -> "void":
        r"""
        Change the offset value.

        Parameters
        ----------
        theOffset: float

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_OffsetCurve_SetOffsetValue(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_GeomEvaluator_OffsetCurve_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _GeomEvaluator.delete_GeomEvaluator_OffsetCurve

# Register GeomEvaluator_OffsetCurve in _GeomEvaluator:
_GeomEvaluator.GeomEvaluator_OffsetCurve_swigregister(GeomEvaluator_OffsetCurve)

class GeomEvaluator_OffsetSurface(GeomEvaluator_Surface):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initialize evaluator by surface.

        Parameters
        ----------
        theBase: Geom_Surface
        theOffset: float
        theOscSurf: Geom_OsculatingSurface,optional
        	default value is opencascade::handle<Geom_OsculatingSurface>()

        Returns
        -------
        None
        Initialize evaluator by surface adaptor.

        Parameters
        ----------
        theBase: GeomAdaptor_HSurface
        theOffset: float
        theOscSurf: Geom_OsculatingSurface,optional
        	default value is opencascade::handle<Geom_OsculatingSurface>()

        Returns
        -------
        None

        """
        _GeomEvaluator.GeomEvaluator_OffsetSurface_swiginit(self, _GeomEvaluator.new_GeomEvaluator_OffsetSurface(*args))

    def SetOffsetValue(self, *args) -> "void":
        r"""
        Change the offset value.

        Parameters
        ----------
        theOffset: float

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_OffsetSurface_SetOffsetValue(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_GeomEvaluator_OffsetSurface_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _GeomEvaluator.delete_GeomEvaluator_OffsetSurface

# Register GeomEvaluator_OffsetSurface in _GeomEvaluator:
_GeomEvaluator.GeomEvaluator_OffsetSurface_swigregister(GeomEvaluator_OffsetSurface)

class GeomEvaluator_SurfaceOfExtrusion(GeomEvaluator_Surface):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initialize evaluator by surface.

        Parameters
        ----------
        theBase: Geom_Curve
        theExtrusionDir: gp_Dir

        Returns
        -------
        None
        Initialize evaluator by surface adaptor.

        Parameters
        ----------
        theBase: Adaptor3d_HCurve
        theExtrusionDir: gp_Dir

        Returns
        -------
        None

        """
        _GeomEvaluator.GeomEvaluator_SurfaceOfExtrusion_swiginit(self, _GeomEvaluator.new_GeomEvaluator_SurfaceOfExtrusion(*args))

    def SetDirection(self, *args) -> "void":
        r"""
        /changes the direction of extrusion.

        Parameters
        ----------
        theDirection: gp_Dir

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_SurfaceOfExtrusion_SetDirection(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_GeomEvaluator_SurfaceOfExtrusion_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _GeomEvaluator.delete_GeomEvaluator_SurfaceOfExtrusion

# Register GeomEvaluator_SurfaceOfExtrusion in _GeomEvaluator:
_GeomEvaluator.GeomEvaluator_SurfaceOfExtrusion_swigregister(GeomEvaluator_SurfaceOfExtrusion)

class GeomEvaluator_SurfaceOfRevolution(GeomEvaluator_Surface):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initialize evaluator by revolved curve, the axis of revolution and the location.

        Parameters
        ----------
        theBase: Geom_Curve
        theRevolDir: gp_Dir
        theRevolLoc: gp_Pnt

        Returns
        -------
        None
        Initialize evaluator by adaptor of the revolved curve, the axis of revolution and the location.

        Parameters
        ----------
        theBase: Adaptor3d_HCurve
        theRevolDir: gp_Dir
        theRevolLoc: gp_Pnt

        Returns
        -------
        None

        """
        _GeomEvaluator.GeomEvaluator_SurfaceOfRevolution_swiginit(self, _GeomEvaluator.new_GeomEvaluator_SurfaceOfRevolution(*args))

    def SetAxis(self, *args) -> "void":
        r"""
        Change the axis of revolution.

        Parameters
        ----------
        theAxis: gp_Ax1

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_SurfaceOfRevolution_SetAxis(self, *args)

    def SetDirection(self, *args) -> "void":
        r"""
        Change direction of the axis of revolution.

        Parameters
        ----------
        theDirection: gp_Dir

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_SurfaceOfRevolution_SetDirection(self, *args)

    def SetLocation(self, *args) -> "void":
        r"""
        Change location of the axis of revolution.

        Parameters
        ----------
        theLocation: gp_Pnt

        Returns
        -------
        None

        """
        return _GeomEvaluator.GeomEvaluator_SurfaceOfRevolution_SetLocation(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_GeomEvaluator_SurfaceOfRevolution_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _GeomEvaluator.delete_GeomEvaluator_SurfaceOfRevolution

# Register GeomEvaluator_SurfaceOfRevolution in _GeomEvaluator:
_GeomEvaluator.GeomEvaluator_SurfaceOfRevolution_swigregister(GeomEvaluator_SurfaceOfRevolution)








# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
IntRes2d module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_intres2d.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _IntRes2d
else:
    import _IntRes2d

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _IntRes2d.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _IntRes2d.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IntRes2d.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IntRes2d.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _IntRes2d.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _IntRes2d.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _IntRes2d.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _IntRes2d.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _IntRes2d.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _IntRes2d.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IntRes2d.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _IntRes2d.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _IntRes2d.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IntRes2d.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IntRes2d.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IntRes2d.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _IntRes2d.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _IntRes2d:
_IntRes2d.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _IntRes2d.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection

from enum import IntEnum
from OCC.Core.Exception import *

IntRes2d_Head = _IntRes2d.IntRes2d_Head
IntRes2d_Middle = _IntRes2d.IntRes2d_Middle
IntRes2d_End = _IntRes2d.IntRes2d_End
IntRes2d_Inside = _IntRes2d.IntRes2d_Inside
IntRes2d_Outside = _IntRes2d.IntRes2d_Outside
IntRes2d_Unknown = _IntRes2d.IntRes2d_Unknown
IntRes2d_In = _IntRes2d.IntRes2d_In
IntRes2d_Out = _IntRes2d.IntRes2d_Out
IntRes2d_Touch = _IntRes2d.IntRes2d_Touch
IntRes2d_Undecided = _IntRes2d.IntRes2d_Undecided


class IntRes2d_Position(IntEnum):
	IntRes2d_Head = 0
	IntRes2d_Middle = 1
	IntRes2d_End = 2
IntRes2d_Head = IntRes2d_Position.IntRes2d_Head
IntRes2d_Middle = IntRes2d_Position.IntRes2d_Middle
IntRes2d_End = IntRes2d_Position.IntRes2d_End

class IntRes2d_Situation(IntEnum):
	IntRes2d_Inside = 0
	IntRes2d_Outside = 1
	IntRes2d_Unknown = 2
IntRes2d_Inside = IntRes2d_Situation.IntRes2d_Inside
IntRes2d_Outside = IntRes2d_Situation.IntRes2d_Outside
IntRes2d_Unknown = IntRes2d_Situation.IntRes2d_Unknown

class IntRes2d_TypeTrans(IntEnum):
	IntRes2d_In = 0
	IntRes2d_Out = 1
	IntRes2d_Touch = 2
	IntRes2d_Undecided = 3
IntRes2d_In = IntRes2d_TypeTrans.IntRes2d_In
IntRes2d_Out = IntRes2d_TypeTrans.IntRes2d_Out
IntRes2d_Touch = IntRes2d_TypeTrans.IntRes2d_Touch
IntRes2d_Undecided = IntRes2d_TypeTrans.IntRes2d_Undecided

class IntRes2d_SequenceOfIntersectionPoint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< IntRes2d_IntersectionPoint >::iterator":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_begin(self)

    def end(self) -> "NCollection_Sequence< IntRes2d_IntersectionPoint >::iterator":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_end(self)

    def cbegin(self) -> "NCollection_Sequence< IntRes2d_IntersectionPoint >::const_iterator":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_cbegin(self)

    def cend(self) -> "NCollection_Sequence< IntRes2d_IntersectionPoint >::const_iterator":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_cend(self)

    def __init__(self, *args):
        _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_swiginit(self, _IntRes2d.new_IntRes2d_SequenceOfIntersectionPoint(*args))

    def Size(self) -> "Standard_Integer":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_Size(self)

    def Length(self) -> "Standard_Integer":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_IsEmpty(self)

    def Reverse(self) -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_Clear(self, theAllocator)

    def Assign(self, theOther: "IntRes2d_SequenceOfIntersectionPoint") -> "NCollection_Sequence< IntRes2d_IntersectionPoint > &":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_Assign(self, theOther)

    def Set(self, theOther: "IntRes2d_SequenceOfIntersectionPoint") -> "NCollection_Sequence< IntRes2d_IntersectionPoint > &":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "IntRes2d_SequenceOfIntersectionPoint") -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_Split(self, theIndex, theSeq)

    def First(self) -> "IntRes2d_IntersectionPoint const &":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_First(self)

    def ChangeFirst(self) -> "IntRes2d_IntersectionPoint &":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_ChangeFirst(self)

    def Last(self) -> "IntRes2d_IntersectionPoint const &":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_Last(self)

    def ChangeLast(self) -> "IntRes2d_IntersectionPoint &":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "IntRes2d_IntersectionPoint const &":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "IntRes2d_IntersectionPoint &":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "IntRes2d_IntersectionPoint &":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "IntRes2d_IntersectionPoint") -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _IntRes2d.delete_IntRes2d_SequenceOfIntersectionPoint

    def __len__(self):
        return self.Size()


# Register IntRes2d_SequenceOfIntersectionPoint in _IntRes2d:
_IntRes2d.IntRes2d_SequenceOfIntersectionPoint_swigregister(IntRes2d_SequenceOfIntersectionPoint)

def IntRes2d_SequenceOfIntersectionPoint_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _IntRes2d.IntRes2d_SequenceOfIntersectionPoint_delNode(theNode, theAl)

class IntRes2d_SequenceOfIntersectionSegment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< IntRes2d_IntersectionSegment >::iterator":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_begin(self)

    def end(self) -> "NCollection_Sequence< IntRes2d_IntersectionSegment >::iterator":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_end(self)

    def cbegin(self) -> "NCollection_Sequence< IntRes2d_IntersectionSegment >::const_iterator":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_cbegin(self)

    def cend(self) -> "NCollection_Sequence< IntRes2d_IntersectionSegment >::const_iterator":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_cend(self)

    def __init__(self, *args):
        _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_swiginit(self, _IntRes2d.new_IntRes2d_SequenceOfIntersectionSegment(*args))

    def Size(self) -> "Standard_Integer":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_Size(self)

    def Length(self) -> "Standard_Integer":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_IsEmpty(self)

    def Reverse(self) -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_Clear(self, theAllocator)

    def Assign(self, theOther: "IntRes2d_SequenceOfIntersectionSegment") -> "NCollection_Sequence< IntRes2d_IntersectionSegment > &":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_Assign(self, theOther)

    def Set(self, theOther: "IntRes2d_SequenceOfIntersectionSegment") -> "NCollection_Sequence< IntRes2d_IntersectionSegment > &":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "IntRes2d_SequenceOfIntersectionSegment") -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_Split(self, theIndex, theSeq)

    def First(self) -> "IntRes2d_IntersectionSegment const &":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_First(self)

    def ChangeFirst(self) -> "IntRes2d_IntersectionSegment &":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_ChangeFirst(self)

    def Last(self) -> "IntRes2d_IntersectionSegment const &":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_Last(self)

    def ChangeLast(self) -> "IntRes2d_IntersectionSegment &":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "IntRes2d_IntersectionSegment const &":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "IntRes2d_IntersectionSegment &":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "IntRes2d_IntersectionSegment &":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "IntRes2d_IntersectionSegment") -> "void":
        return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _IntRes2d.delete_IntRes2d_SequenceOfIntersectionSegment

    def __len__(self):
        return self.Size()


# Register IntRes2d_SequenceOfIntersectionSegment in _IntRes2d:
_IntRes2d.IntRes2d_SequenceOfIntersectionSegment_swigregister(IntRes2d_SequenceOfIntersectionSegment)

def IntRes2d_SequenceOfIntersectionSegment_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _IntRes2d.IntRes2d_SequenceOfIntersectionSegment_delNode(theNode, theAl)

class IntRes2d_Domain(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates an infinite domain (hasfirstpoint = false and haslastpoint = false).

        Returns
        -------
        None
        Creates a bounded domain.

        Parameters
        ----------
        Pnt1: gp_Pnt2d
        Par1: float
        Tol1: float
        Pnt2: gp_Pnt2d
        Par2: float
        Tol2: float

        Returns
        -------
        None
        Creates a semi-infinite domain. if first is set to true, the given point is the first point of the domain, otherwise it is the last point.

        Parameters
        ----------
        Pnt: gp_Pnt2d
        Par: float
        Tol: float
        First: bool

        Returns
        -------
        None

        """
        _IntRes2d.IntRes2d_Domain_swiginit(self, _IntRes2d.new_IntRes2d_Domain(*args))

    def EquivalentParameters(self, *args) -> "void":
        r"""
        Returns equivalent parameters if the domain is closed. otherwise, the exception domainerror is raised.

        Parameters
        ----------

        Returns
        -------
        zero: float
        zeroplusperiod: float

        """
        return _IntRes2d.IntRes2d_Domain_EquivalentParameters(self, *args)

    def FirstParameter(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter of the first point of the domain the exception domainerror is raised if hasfirstpoint returns false.

        Returns
        -------
        float

        """
        return _IntRes2d.IntRes2d_Domain_FirstParameter(self, *args)

    def FirstPoint(self, *args) -> "gp_Pnt2d const":
        r"""
        Returns the first point of the domain. the exception domainerror is raised if hasfirstpoint returns false.

        Returns
        -------
        gp_Pnt2d

        """
        return _IntRes2d.IntRes2d_Domain_FirstPoint(self, *args)

    def FirstTolerance(self, *args) -> "Standard_Real":
        r"""
        Returns the tolerance of the first (left) bound. the exception domainerror is raised if hasfirstpoint returns false.

        Returns
        -------
        float

        """
        return _IntRes2d.IntRes2d_Domain_FirstTolerance(self, *args)

    def HasFirstPoint(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the domain has a first point, i-e a point defining the lowest admitted parameter on the curve.

        Returns
        -------
        bool

        """
        return _IntRes2d.IntRes2d_Domain_HasFirstPoint(self, *args)

    def HasLastPoint(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the domain has a last point, i-e a point defining the highest admitted parameter on the curve.

        Returns
        -------
        bool

        """
        return _IntRes2d.IntRes2d_Domain_HasLastPoint(self, *args)

    def IsClosed(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the domain is closed.

        Returns
        -------
        bool

        """
        return _IntRes2d.IntRes2d_Domain_IsClosed(self, *args)

    def LastParameter(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter of the last point of the domain. the exception domainerror is raised if haslastpoint returns false.

        Returns
        -------
        float

        """
        return _IntRes2d.IntRes2d_Domain_LastParameter(self, *args)

    def LastPoint(self, *args) -> "gp_Pnt2d const":
        r"""
        Returns the last point of the domain. the exception domainerror is raised if haslastpoint returns false.

        Returns
        -------
        gp_Pnt2d

        """
        return _IntRes2d.IntRes2d_Domain_LastPoint(self, *args)

    def LastTolerance(self, *args) -> "Standard_Real":
        r"""
        Returns the tolerance of the last (right) bound. the exception domainerror is raised if haslastpoint returns false.

        Returns
        -------
        float

        """
        return _IntRes2d.IntRes2d_Domain_LastTolerance(self, *args)

    def SetEquivalentParameters(self, *args) -> "void":
        r"""
        Defines a closed domain.

        Parameters
        ----------
        zero: float
        period: float

        Returns
        -------
        None

        """
        return _IntRes2d.IntRes2d_Domain_SetEquivalentParameters(self, *args)

    def SetValues(self, *args) -> "void":
        r"""
        Sets the values for a bounded domain.

        Parameters
        ----------
        Pnt1: gp_Pnt2d
        Par1: float
        Tol1: float
        Pnt2: gp_Pnt2d
        Par2: float
        Tol2: float

        Returns
        -------
        None
        Sets the values for an infinite domain.

        Returns
        -------
        None
        Sets the values for a semi-infinite domain.

        Parameters
        ----------
        Pnt: gp_Pnt2d
        Par: float
        Tol: float
        First: bool

        Returns
        -------
        None

        """
        return _IntRes2d.IntRes2d_Domain_SetValues(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IntRes2d.delete_IntRes2d_Domain

# Register IntRes2d_Domain in _IntRes2d:
_IntRes2d.IntRes2d_Domain_swigregister(IntRes2d_Domain)

class IntRes2d_Intersection(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true when the computation was successful.

        Returns
        -------
        bool

        """
        return _IntRes2d.IntRes2d_Intersection_IsDone(self, *args)

    def IsEmpty(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if there is no intersection between the given arguments. the exception notdone is raised if isdone returns false.

        Returns
        -------
        bool

        """
        return _IntRes2d.IntRes2d_Intersection_IsEmpty(self, *args)

    def NbPoints(self, *args) -> "Standard_Integer":
        r"""
        This function returns the number of intersection points between the 2 curves. the exception notdone is raised if isdone returns false.

        Returns
        -------
        int

        """
        return _IntRes2d.IntRes2d_Intersection_NbPoints(self, *args)

    def NbSegments(self, *args) -> "Standard_Integer":
        r"""
        This function returns the number of intersection segments between the two curves. the exception notdone is raised if isdone returns false.

        Returns
        -------
        int

        """
        return _IntRes2d.IntRes2d_Intersection_NbSegments(self, *args)

    def Point(self, *args) -> "IntRes2d_IntersectionPoint const &":
        r"""
        This function returns the intersection point of range n; the exception notdone is raised if isdone returns false. the exception outofrange is raised if (n <= 0) or (n > nbpoints).

        Parameters
        ----------
        N: int

        Returns
        -------
        IntRes2d_IntersectionPoint

        """
        return _IntRes2d.IntRes2d_Intersection_Point(self, *args)

    def Segment(self, *args) -> "IntRes2d_IntersectionSegment const &":
        r"""
        This function returns the intersection segment of range n; the exception notdone is raised if isdone returns false. the exception outofrange is raised if (n <= 0) or (n > nbpoints).

        Parameters
        ----------
        N: int

        Returns
        -------
        IntRes2d_IntersectionSegment

        """
        return _IntRes2d.IntRes2d_Intersection_Segment(self, *args)

    def SetReversedParameters(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Reverseflag: bool

        Returns
        -------
        None

        """
        return _IntRes2d.IntRes2d_Intersection_SetReversedParameters(self, *args)

    __repr__ = _dumps_object


# Register IntRes2d_Intersection in _IntRes2d:
_IntRes2d.IntRes2d_Intersection_swigregister(IntRes2d_Intersection)

class IntRes2d_IntersectionPoint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None
        Creates an intersectionpoint. if reversedflag is false, the parameter uc1(resp. uc2) and the transition trans1 (resp. trans2) refer to the first curve (resp. second curve) otherwise uc1 and trans1 (resp. uc2 and trans2) refer to the second curve (resp. the first curve).

        Parameters
        ----------
        P: gp_Pnt2d
        Uc1: float
        Uc2: float
        Trans1: IntRes2d_Transition
        Trans2: IntRes2d_Transition
        ReversedFlag: bool

        Returns
        -------
        None

        """
        _IntRes2d.IntRes2d_IntersectionPoint_swiginit(self, _IntRes2d.new_IntRes2d_IntersectionPoint(*args))

    def ParamOnFirst(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter on the first curve.

        Returns
        -------
        float

        """
        return _IntRes2d.IntRes2d_IntersectionPoint_ParamOnFirst(self, *args)

    def ParamOnSecond(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter on the second curve.

        Returns
        -------
        float

        """
        return _IntRes2d.IntRes2d_IntersectionPoint_ParamOnSecond(self, *args)

    def SetValues(self, *args) -> "void":
        r"""
        Sets the values for an existing intersection point. the meaning of the parameters are the same as for the create.

        Parameters
        ----------
        P: gp_Pnt2d
        Uc1: float
        Uc2: float
        Trans1: IntRes2d_Transition
        Trans2: IntRes2d_Transition
        ReversedFlag: bool

        Returns
        -------
        None

        """
        return _IntRes2d.IntRes2d_IntersectionPoint_SetValues(self, *args)

    def TransitionOfFirst(self, *args) -> "IntRes2d_Transition const &":
        r"""
        Returns the transition of the 1st curve compared to the 2nd one.

        Returns
        -------
        IntRes2d_Transition

        """
        return _IntRes2d.IntRes2d_IntersectionPoint_TransitionOfFirst(self, *args)

    def TransitionOfSecond(self, *args) -> "IntRes2d_Transition const &":
        r"""
        Returns the transition of the 2nd curve compared to the 1st one.

        Returns
        -------
        IntRes2d_Transition

        """
        return _IntRes2d.IntRes2d_IntersectionPoint_TransitionOfSecond(self, *args)

    def Value(self, *args) -> "gp_Pnt2d const":
        r"""
        Returns the value of the coordinates of the intersection point in the 2d space.

        Returns
        -------
        gp_Pnt2d

        """
        return _IntRes2d.IntRes2d_IntersectionPoint_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IntRes2d.delete_IntRes2d_IntersectionPoint

# Register IntRes2d_IntersectionPoint in _IntRes2d:
_IntRes2d.IntRes2d_IntersectionPoint_swigregister(IntRes2d_IntersectionPoint)

class IntRes2d_IntersectionSegment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        P1: IntRes2d_IntersectionPoint
        P2: IntRes2d_IntersectionPoint
        Oppos: bool
        ReverseFlag: bool

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        P: IntRes2d_IntersectionPoint
        First: bool
        Oppos: bool
        ReverseFlag: bool

        Returns
        -------
        None
        Creates an infinite segment of intersection.

        Parameters
        ----------
        Oppos: bool

        Returns
        -------
        None

        """
        _IntRes2d.IntRes2d_IntersectionSegment_swiginit(self, _IntRes2d.new_IntRes2d_IntersectionSegment(*args))

    def FirstPoint(self, *args) -> "IntRes2d_IntersectionPoint const &":
        r"""
        Returns the first point of the segment as an intersectionpoint (with a transition). the exception domainerror is raised if hasfirstpoint returns false.

        Returns
        -------
        IntRes2d_IntersectionPoint

        """
        return _IntRes2d.IntRes2d_IntersectionSegment_FirstPoint(self, *args)

    def HasFirstPoint(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the segment is limited by a first point. this point defines the lowest parameter admitted on the first curve for the segment. if isopposite returns false, it defines the lowest parameter on the second curve, otherwise, it is the highest parameter on the second curve.

        Returns
        -------
        bool

        """
        return _IntRes2d.IntRes2d_IntersectionSegment_HasFirstPoint(self, *args)

    def HasLastPoint(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the segment is limited by a last point. this point defines the highest parameter admitted on the first curve for the segment. if isopposite returns false, it defines the highest parameter on the second curve, otherwise, it is the lowest parameter on the second curve.

        Returns
        -------
        bool

        """
        return _IntRes2d.IntRes2d_IntersectionSegment_HasLastPoint(self, *args)

    def IsOpposite(self, *args) -> "Standard_Boolean":
        r"""
        Returns false if the intersection segment has got the same orientation on both curves.

        Returns
        -------
        bool

        """
        return _IntRes2d.IntRes2d_IntersectionSegment_IsOpposite(self, *args)

    def LastPoint(self, *args) -> "IntRes2d_IntersectionPoint const &":
        r"""
        Returns the last point of the segment as an intersectionpoint (with a transition). the exception domainerror is raised if haslastextremity returns false.

        Returns
        -------
        IntRes2d_IntersectionPoint

        """
        return _IntRes2d.IntRes2d_IntersectionSegment_LastPoint(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IntRes2d.delete_IntRes2d_IntersectionSegment

# Register IntRes2d_IntersectionSegment in _IntRes2d:
_IntRes2d.IntRes2d_IntersectionSegment_swigregister(IntRes2d_IntersectionSegment)

class IntRes2d_Transition(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None
        Creates an in or out transition.

        Parameters
        ----------
        Tangent: bool
        Pos: IntRes2d_Position
        Type: IntRes2d_TypeTrans

        Returns
        -------
        None
        Creates a touch transition.

        Parameters
        ----------
        Tangent: bool
        Pos: IntRes2d_Position
        Situ: IntRes2d_Situation
        Oppos: bool

        Returns
        -------
        None
        Creates an undecided transition.

        Parameters
        ----------
        Pos: IntRes2d_Position

        Returns
        -------
        None

        """
        _IntRes2d.IntRes2d_Transition_swiginit(self, _IntRes2d.new_IntRes2d_Transition(*args))

    def IsOpposite(self, *args) -> "Standard_Boolean":
        r"""
        Returns a significant value if transitiontype returns touch. in this case, the function returns true when the 2 curves locally define two different parts of the space. if transitiontype returns in or out or undecided, the exception domainerror is raised.

        Returns
        -------
        bool

        """
        return _IntRes2d.IntRes2d_Transition_IsOpposite(self, *args)

    def IsTangent(self, *args) -> "Standard_Boolean":
        r"""
        Returns true when the 2 curves are tangent at the intersection point. theexception domainerror is raised if the type of transition is undecided.

        Returns
        -------
        bool

        """
        return _IntRes2d.IntRes2d_Transition_IsTangent(self, *args)

    def PositionOnCurve(self, *args) -> "IntRes2d_Position":
        r"""
        Indicates if the intersection is at the beginning (intres2d_head), at the end (intres2d_end), or in the middle (intres2d_middle) of the curve.

        Returns
        -------
        IntRes2d_Position

        """
        return _IntRes2d.IntRes2d_Transition_PositionOnCurve(self, *args)

    def SetPosition(self, *args) -> "void":
        r"""
        Sets the value of the position.

        Parameters
        ----------
        Pos: IntRes2d_Position

        Returns
        -------
        None

        """
        return _IntRes2d.IntRes2d_Transition_SetPosition(self, *args)

    def SetValue(self, *args) -> "void":
        r"""
        Sets the values of an in or out transition.

        Parameters
        ----------
        Tangent: bool
        Pos: IntRes2d_Position
        Type: IntRes2d_TypeTrans

        Returns
        -------
        None
        Sets the values of a touch transition.

        Parameters
        ----------
        Tangent: bool
        Pos: IntRes2d_Position
        Situ: IntRes2d_Situation
        Oppos: bool

        Returns
        -------
        None
        Sets the values of an undecided transition.

        Parameters
        ----------
        Pos: IntRes2d_Position

        Returns
        -------
        None

        """
        return _IntRes2d.IntRes2d_Transition_SetValue(self, *args)

    def Situation(self, *args) -> "IntRes2d_Situation":
        r"""
        Returns a significant value if transitiontype returns touch. in this case, the function returns : inside when the curve remains inside the other one, outside when it remains outside the other one, unknown when the calculus, based on the second derivatives cannot give the result. if transitiontype returns in or out or undecided, the exception domainerror is raised.

        Returns
        -------
        IntRes2d_Situation

        """
        return _IntRes2d.IntRes2d_Transition_Situation(self, *args)

    def TransitionType(self, *args) -> "IntRes2d_TypeTrans":
        r"""
        Returns the type of transition at the intersection. it may be in or out or touch, or undecided if the two first derivatives are not enough to give the tangent to one of the two curves.

        Returns
        -------
        IntRes2d_TypeTrans

        """
        return _IntRes2d.IntRes2d_Transition_TransitionType(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IntRes2d.delete_IntRes2d_Transition

# Register IntRes2d_Transition in _IntRes2d:
_IntRes2d.IntRes2d_Transition_swigregister(IntRes2d_Transition)








# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
FEmTool module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_femtool.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _FEmTool
else:
    import _FEmTool

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _FEmTool.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _FEmTool.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _FEmTool.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _FEmTool.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _FEmTool.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _FEmTool.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _FEmTool.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _FEmTool.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _FEmTool.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _FEmTool.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _FEmTool.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _FEmTool.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _FEmTool.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _FEmTool.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _FEmTool.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _FEmTool.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _FEmTool.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _FEmTool:
_FEmTool.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _FEmTool.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.math
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.gp
import OCC.Core.PLib
import OCC.Core.TColgp
import OCC.Core.GeomAbs

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_FEmTool_Curve_Create() -> "opencascade::handle< FEmTool_Curve >":
    return _FEmTool.Handle_FEmTool_Curve_Create()

def Handle_FEmTool_Curve_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< FEmTool_Curve >":
    return _FEmTool.Handle_FEmTool_Curve_DownCast(t)

def Handle_FEmTool_Curve_IsNull(t: "opencascade::handle< FEmTool_Curve > const &") -> "bool":
    return _FEmTool.Handle_FEmTool_Curve_IsNull(t)

def Handle_FEmTool_ElementaryCriterion_Create() -> "opencascade::handle< FEmTool_ElementaryCriterion >":
    return _FEmTool.Handle_FEmTool_ElementaryCriterion_Create()

def Handle_FEmTool_ElementaryCriterion_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< FEmTool_ElementaryCriterion >":
    return _FEmTool.Handle_FEmTool_ElementaryCriterion_DownCast(t)

def Handle_FEmTool_ElementaryCriterion_IsNull(t: "opencascade::handle< FEmTool_ElementaryCriterion > const &") -> "bool":
    return _FEmTool.Handle_FEmTool_ElementaryCriterion_IsNull(t)

def Handle_FEmTool_SparseMatrix_Create() -> "opencascade::handle< FEmTool_SparseMatrix >":
    return _FEmTool.Handle_FEmTool_SparseMatrix_Create()

def Handle_FEmTool_SparseMatrix_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< FEmTool_SparseMatrix >":
    return _FEmTool.Handle_FEmTool_SparseMatrix_DownCast(t)

def Handle_FEmTool_SparseMatrix_IsNull(t: "opencascade::handle< FEmTool_SparseMatrix > const &") -> "bool":
    return _FEmTool.Handle_FEmTool_SparseMatrix_IsNull(t)

def Handle_FEmTool_LinearFlexion_Create() -> "opencascade::handle< FEmTool_LinearFlexion >":
    return _FEmTool.Handle_FEmTool_LinearFlexion_Create()

def Handle_FEmTool_LinearFlexion_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< FEmTool_LinearFlexion >":
    return _FEmTool.Handle_FEmTool_LinearFlexion_DownCast(t)

def Handle_FEmTool_LinearFlexion_IsNull(t: "opencascade::handle< FEmTool_LinearFlexion > const &") -> "bool":
    return _FEmTool.Handle_FEmTool_LinearFlexion_IsNull(t)

def Handle_FEmTool_LinearJerk_Create() -> "opencascade::handle< FEmTool_LinearJerk >":
    return _FEmTool.Handle_FEmTool_LinearJerk_Create()

def Handle_FEmTool_LinearJerk_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< FEmTool_LinearJerk >":
    return _FEmTool.Handle_FEmTool_LinearJerk_DownCast(t)

def Handle_FEmTool_LinearJerk_IsNull(t: "opencascade::handle< FEmTool_LinearJerk > const &") -> "bool":
    return _FEmTool.Handle_FEmTool_LinearJerk_IsNull(t)

def Handle_FEmTool_LinearTension_Create() -> "opencascade::handle< FEmTool_LinearTension >":
    return _FEmTool.Handle_FEmTool_LinearTension_Create()

def Handle_FEmTool_LinearTension_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< FEmTool_LinearTension >":
    return _FEmTool.Handle_FEmTool_LinearTension_DownCast(t)

def Handle_FEmTool_LinearTension_IsNull(t: "opencascade::handle< FEmTool_LinearTension > const &") -> "bool":
    return _FEmTool.Handle_FEmTool_LinearTension_IsNull(t)

def Handle_FEmTool_ProfileMatrix_Create() -> "opencascade::handle< FEmTool_ProfileMatrix >":
    return _FEmTool.Handle_FEmTool_ProfileMatrix_Create()

def Handle_FEmTool_ProfileMatrix_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< FEmTool_ProfileMatrix >":
    return _FEmTool.Handle_FEmTool_ProfileMatrix_DownCast(t)

def Handle_FEmTool_ProfileMatrix_IsNull(t: "opencascade::handle< FEmTool_ProfileMatrix > const &") -> "bool":
    return _FEmTool.Handle_FEmTool_ProfileMatrix_IsNull(t)

def Handle_FEmTool_HAssemblyTable_Create() -> "opencascade::handle< FEmTool_HAssemblyTable >":
    return _FEmTool.Handle_FEmTool_HAssemblyTable_Create()

def Handle_FEmTool_HAssemblyTable_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< FEmTool_HAssemblyTable >":
    return _FEmTool.Handle_FEmTool_HAssemblyTable_DownCast(t)

def Handle_FEmTool_HAssemblyTable_IsNull(t: "opencascade::handle< FEmTool_HAssemblyTable > const &") -> "bool":
    return _FEmTool.Handle_FEmTool_HAssemblyTable_IsNull(t)
class FEmTool_AssemblyTable(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _FEmTool.FEmTool_AssemblyTable_swiginit(self, _FEmTool.new_FEmTool_AssemblyTable(*args))

    def Init(self, theValue: "opencascade::handle< TColStd_HArray1OfInteger > const &") -> "void":
        return _FEmTool.FEmTool_AssemblyTable_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _FEmTool.FEmTool_AssemblyTable_Size(self)

    def Length(self) -> "Standard_Integer":
        return _FEmTool.FEmTool_AssemblyTable_Length(self)

    def NbRows(self) -> "Standard_Integer":
        return _FEmTool.FEmTool_AssemblyTable_NbRows(self)

    def NbColumns(self) -> "Standard_Integer":
        return _FEmTool.FEmTool_AssemblyTable_NbColumns(self)

    def RowLength(self) -> "Standard_Integer":
        return _FEmTool.FEmTool_AssemblyTable_RowLength(self)

    def ColLength(self) -> "Standard_Integer":
        return _FEmTool.FEmTool_AssemblyTable_ColLength(self)

    def LowerRow(self) -> "Standard_Integer":
        return _FEmTool.FEmTool_AssemblyTable_LowerRow(self)

    def UpperRow(self) -> "Standard_Integer":
        return _FEmTool.FEmTool_AssemblyTable_UpperRow(self)

    def LowerCol(self) -> "Standard_Integer":
        return _FEmTool.FEmTool_AssemblyTable_LowerCol(self)

    def UpperCol(self) -> "Standard_Integer":
        return _FEmTool.FEmTool_AssemblyTable_UpperCol(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _FEmTool.FEmTool_AssemblyTable_IsDeletable(self)

    def Assign(self, theOther: "FEmTool_AssemblyTable") -> "NCollection_Array2< opencascade::handle< TColStd_HArray1OfInteger > > &":
        return _FEmTool.FEmTool_AssemblyTable_Assign(self, theOther)

    def Move(self, theOther: "FEmTool_AssemblyTable") -> "NCollection_Array2< opencascade::handle< TColStd_HArray1OfInteger > > &":
        return _FEmTool.FEmTool_AssemblyTable_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array2< opencascade::handle< TColStd_HArray1OfInteger > > &":
        return _FEmTool.FEmTool_AssemblyTable_Set(self, *args)

    def Value(self, theRow: "Standard_Integer const", theCol: "Standard_Integer const") -> "opencascade::handle< TColStd_HArray1OfInteger > const &":
        return _FEmTool.FEmTool_AssemblyTable_Value(self, theRow, theCol)

    def ChangeValue(self, theRow: "Standard_Integer const", theCol: "Standard_Integer const") -> "opencascade::handle< TColStd_HArray1OfInteger > &":
        return _FEmTool.FEmTool_AssemblyTable_ChangeValue(self, theRow, theCol)

    def __call__(self, *args) -> "opencascade::handle< TColStd_HArray1OfInteger > &":
        return _FEmTool.FEmTool_AssemblyTable___call__(self, *args)

    def SetValue(self, theRow: "Standard_Integer const", theCol: "Standard_Integer const", theItem: "opencascade::handle< TColStd_HArray1OfInteger > const &") -> "void":
        return _FEmTool.FEmTool_AssemblyTable_SetValue(self, theRow, theCol, theItem)

    def Resize(self, theRowLower: "Standard_Integer", theRowUpper: "Standard_Integer", theColLower: "Standard_Integer", theColUpper: "Standard_Integer", theToCopyData: "Standard_Boolean") -> "void":
        return _FEmTool.FEmTool_AssemblyTable_Resize(self, theRowLower, theRowUpper, theColLower, theColUpper, theToCopyData)
    __swig_destroy__ = _FEmTool.delete_FEmTool_AssemblyTable

# Register FEmTool_AssemblyTable in _FEmTool:
_FEmTool.FEmTool_AssemblyTable_swigregister(FEmTool_AssemblyTable)

class FEmTool_ListIteratorOfListOfVectors(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _FEmTool.FEmTool_ListIteratorOfListOfVectors_swiginit(self, _FEmTool.new_FEmTool_ListIteratorOfListOfVectors(*args))

    def More(self) -> "Standard_Boolean":
        return _FEmTool.FEmTool_ListIteratorOfListOfVectors_More(self)

    def Next(self) -> "void":
        return _FEmTool.FEmTool_ListIteratorOfListOfVectors_Next(self)

    def Value(self) -> "opencascade::handle< TColStd_HArray1OfReal > const &":
        return _FEmTool.FEmTool_ListIteratorOfListOfVectors_Value(self)

    def ChangeValue(self) -> "opencascade::handle< TColStd_HArray1OfReal > &":
        return _FEmTool.FEmTool_ListIteratorOfListOfVectors_ChangeValue(self)
    __swig_destroy__ = _FEmTool.delete_FEmTool_ListIteratorOfListOfVectors

# Register FEmTool_ListIteratorOfListOfVectors in _FEmTool:
_FEmTool.FEmTool_ListIteratorOfListOfVectors_swigregister(FEmTool_ListIteratorOfListOfVectors)

class FEmTool_ListOfVectors(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_List< opencascade::handle< TColStd_HArray1OfReal > >::iterator":
        return _FEmTool.FEmTool_ListOfVectors_begin(self)

    def end(self) -> "NCollection_List< opencascade::handle< TColStd_HArray1OfReal > >::iterator":
        return _FEmTool.FEmTool_ListOfVectors_end(self)

    def cbegin(self) -> "NCollection_List< opencascade::handle< TColStd_HArray1OfReal > >::const_iterator":
        return _FEmTool.FEmTool_ListOfVectors_cbegin(self)

    def cend(self) -> "NCollection_List< opencascade::handle< TColStd_HArray1OfReal > >::const_iterator":
        return _FEmTool.FEmTool_ListOfVectors_cend(self)

    def __init__(self, *args):
        _FEmTool.FEmTool_ListOfVectors_swiginit(self, _FEmTool.new_FEmTool_ListOfVectors(*args))

    def Size(self) -> "Standard_Integer":
        return _FEmTool.FEmTool_ListOfVectors_Size(self)

    def Assign(self, theOther: "FEmTool_ListOfVectors") -> "NCollection_List< opencascade::handle< TColStd_HArray1OfReal > > &":
        return _FEmTool.FEmTool_ListOfVectors_Assign(self, theOther)

    def Set(self, theOther: "FEmTool_ListOfVectors") -> "NCollection_List< opencascade::handle< TColStd_HArray1OfReal > > &":
        return _FEmTool.FEmTool_ListOfVectors_Set(self, theOther)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _FEmTool.FEmTool_ListOfVectors_Clear(self, theAllocator)

    def First(self) -> "opencascade::handle< TColStd_HArray1OfReal > const &":
        return _FEmTool.FEmTool_ListOfVectors_First(self)

    def Last(self) -> "opencascade::handle< TColStd_HArray1OfReal > const &":
        return _FEmTool.FEmTool_ListOfVectors_Last(self)

    def Append(self, *args) -> "void":
        return _FEmTool.FEmTool_ListOfVectors_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _FEmTool.FEmTool_ListOfVectors_Prepend(self, *args)

    def RemoveFirst(self) -> "void":
        return _FEmTool.FEmTool_ListOfVectors_RemoveFirst(self)

    def Remove(self, theIter: "FEmTool_ListIteratorOfListOfVectors") -> "void":
        return _FEmTool.FEmTool_ListOfVectors_Remove(self, theIter)

    def InsertBefore(self, *args) -> "void":
        return _FEmTool.FEmTool_ListOfVectors_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _FEmTool.FEmTool_ListOfVectors_InsertAfter(self, *args)

    def Reverse(self) -> "void":
        return _FEmTool.FEmTool_ListOfVectors_Reverse(self)
    __swig_destroy__ = _FEmTool.delete_FEmTool_ListOfVectors

    def __len__(self):
        return self.Size()


# Register FEmTool_ListOfVectors in _FEmTool:
_FEmTool.FEmTool_ListOfVectors_swigregister(FEmTool_ListOfVectors)

class FEmTool_SeqOfLinConstr(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< FEmTool_ListOfVectors >::iterator":
        return _FEmTool.FEmTool_SeqOfLinConstr_begin(self)

    def end(self) -> "NCollection_Sequence< FEmTool_ListOfVectors >::iterator":
        return _FEmTool.FEmTool_SeqOfLinConstr_end(self)

    def cbegin(self) -> "NCollection_Sequence< FEmTool_ListOfVectors >::const_iterator":
        return _FEmTool.FEmTool_SeqOfLinConstr_cbegin(self)

    def cend(self) -> "NCollection_Sequence< FEmTool_ListOfVectors >::const_iterator":
        return _FEmTool.FEmTool_SeqOfLinConstr_cend(self)

    def __init__(self, *args):
        _FEmTool.FEmTool_SeqOfLinConstr_swiginit(self, _FEmTool.new_FEmTool_SeqOfLinConstr(*args))

    def Size(self) -> "Standard_Integer":
        return _FEmTool.FEmTool_SeqOfLinConstr_Size(self)

    def Length(self) -> "Standard_Integer":
        return _FEmTool.FEmTool_SeqOfLinConstr_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _FEmTool.FEmTool_SeqOfLinConstr_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _FEmTool.FEmTool_SeqOfLinConstr_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _FEmTool.FEmTool_SeqOfLinConstr_IsEmpty(self)

    def Reverse(self) -> "void":
        return _FEmTool.FEmTool_SeqOfLinConstr_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _FEmTool.FEmTool_SeqOfLinConstr_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _FEmTool.FEmTool_SeqOfLinConstr_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _FEmTool.FEmTool_SeqOfLinConstr_Clear(self, theAllocator)

    def Assign(self, theOther: "FEmTool_SeqOfLinConstr") -> "NCollection_Sequence< FEmTool_ListOfVectors > &":
        return _FEmTool.FEmTool_SeqOfLinConstr_Assign(self, theOther)

    def Set(self, theOther: "FEmTool_SeqOfLinConstr") -> "NCollection_Sequence< FEmTool_ListOfVectors > &":
        return _FEmTool.FEmTool_SeqOfLinConstr_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _FEmTool.FEmTool_SeqOfLinConstr_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _FEmTool.FEmTool_SeqOfLinConstr_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _FEmTool.FEmTool_SeqOfLinConstr_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _FEmTool.FEmTool_SeqOfLinConstr_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _FEmTool.FEmTool_SeqOfLinConstr_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "FEmTool_SeqOfLinConstr") -> "void":
        return _FEmTool.FEmTool_SeqOfLinConstr_Split(self, theIndex, theSeq)

    def First(self) -> "FEmTool_ListOfVectors const &":
        return _FEmTool.FEmTool_SeqOfLinConstr_First(self)

    def ChangeFirst(self) -> "FEmTool_ListOfVectors &":
        return _FEmTool.FEmTool_SeqOfLinConstr_ChangeFirst(self)

    def Last(self) -> "FEmTool_ListOfVectors const &":
        return _FEmTool.FEmTool_SeqOfLinConstr_Last(self)

    def ChangeLast(self) -> "FEmTool_ListOfVectors &":
        return _FEmTool.FEmTool_SeqOfLinConstr_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "FEmTool_ListOfVectors const &":
        return _FEmTool.FEmTool_SeqOfLinConstr_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "FEmTool_ListOfVectors &":
        return _FEmTool.FEmTool_SeqOfLinConstr_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "FEmTool_ListOfVectors &":
        return _FEmTool.FEmTool_SeqOfLinConstr___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "FEmTool_ListOfVectors") -> "void":
        return _FEmTool.FEmTool_SeqOfLinConstr_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _FEmTool.delete_FEmTool_SeqOfLinConstr

    def __len__(self):
        return self.Size()


# Register FEmTool_SeqOfLinConstr in _FEmTool:
_FEmTool.FEmTool_SeqOfLinConstr_swigregister(FEmTool_SeqOfLinConstr)

def FEmTool_SeqOfLinConstr_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _FEmTool.FEmTool_SeqOfLinConstr_delNode(theNode, theAl)

class FEmTool_Assembly(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        Dependence: TColStd_Array2OfInteger
        Table: FEmTool_HAssemblyTable

        Returns
        -------
        None

        """
        _FEmTool.FEmTool_Assembly_swiginit(self, _FEmTool.new_FEmTool_Assembly(*args))

    def AddConstraint(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        IndexofConstraint: int
        Element: int
        Dimension: int
        LinearForm: math_Vector
        Value: float

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_Assembly_AddConstraint(self, *args)

    def AddMatrix(self, *args) -> "void":
        r"""
        Add an elementary matrix in the assembly matrix if dependence(dimension1,dimension2) is false.

        Parameters
        ----------
        Element: int
        Dimension1: int
        Dimension2: int
        Mat: math_Matrix

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_Assembly_AddMatrix(self, *args)

    def AddVector(self, *args) -> "void":
        r"""
        Add an elementary vector in the assembly vector (second member).

        Parameters
        ----------
        Element: int
        Dimension: int
        Vec: math_Vector

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_Assembly_AddVector(self, *args)

    def GetAssemblyTable(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        AssTable: FEmTool_HAssemblyTable

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_Assembly_GetAssemblyTable(self, *args)

    def NbGlobVar(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _FEmTool.FEmTool_Assembly_NbGlobVar(self, *args)

    def NullifyConstraint(self, *args) -> "void":
        r"""
        Nullify all constraints.

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_Assembly_NullifyConstraint(self, *args)

    def NullifyMatrix(self, *args) -> "void":
        r"""
        Nullify all matrix 's coefficient.

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_Assembly_NullifyMatrix(self, *args)

    def NullifyVector(self, *args) -> "void":
        r"""
        Nullify all coordinate of assembly vector (second member).

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_Assembly_NullifyVector(self, *args)

    def ResetConstraint(self, *args) -> "void":
        r"""
        Delete all constraints.

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_Assembly_ResetConstraint(self, *args)

    def Solution(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Solution: math_Vector

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_Assembly_Solution(self, *args)

    def Solve(self, *args) -> "Standard_Boolean":
        r"""
        Solve the assembly system returns standard_false if the computation failed.

        Returns
        -------
        bool

        """
        return _FEmTool.FEmTool_Assembly_Solve(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _FEmTool.delete_FEmTool_Assembly

# Register FEmTool_Assembly in _FEmTool:
_FEmTool.FEmTool_Assembly_swigregister(FEmTool_Assembly)

class FEmTool_Curve(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        Dimension: int
        NbElements: int
        TheBase: PLib_Base
        Tolerance: float

        Returns
        -------
        None

        """
        _FEmTool.FEmTool_Curve_swiginit(self, _FEmTool.new_FEmTool_Curve(*args))

    def Base(self, *args) -> "opencascade::handle< PLib_Base >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<PLib_Base>

        """
        return _FEmTool.FEmTool_Curve_Base(self, *args)

    def D0(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        Pnt: TColStd_Array1OfReal

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_Curve_D0(self, *args)

    def D1(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        Vec: TColStd_Array1OfReal

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_Curve_D1(self, *args)

    def D2(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        Vec: TColStd_Array1OfReal

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_Curve_D2(self, *args)

    def Degree(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        IndexOfElement: int

        Returns
        -------
        int

        """
        return _FEmTool.FEmTool_Curve_Degree(self, *args)

    def Dimension(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _FEmTool.FEmTool_Curve_Dimension(self, *args)

    def GetElement(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        IndexOfElement: int
        Coeffs: TColStd_Array2OfReal

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_Curve_GetElement(self, *args)

    def GetPolynom(self, *args) -> "void":
        r"""
        Returns coefficients of all elements in canonical base.

        Parameters
        ----------
        Coeffs: TColStd_Array1OfReal

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_Curve_GetPolynom(self, *args)

    def Knots(self, *args) -> "TColStd_Array1OfReal &":
        r"""
        No available documentation.

        Returns
        -------
        TColStd_Array1OfReal

        """
        return _FEmTool.FEmTool_Curve_Knots(self, *args)

    def Length(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        FirstU: float
        LastU: float

        Returns
        -------
        Length: float

        """
        return _FEmTool.FEmTool_Curve_Length(self, *args)

    def NbElements(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _FEmTool.FEmTool_Curve_NbElements(self, *args)

    def ReduceDegree(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        IndexOfElement: int
        Tol: float

        Returns
        -------
        NewDegree: int
        MaxError: float

        """
        return _FEmTool.FEmTool_Curve_ReduceDegree(self, *args)

    def SetDegree(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        IndexOfElement: int
        Degree: int

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_Curve_SetDegree(self, *args)

    def SetElement(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        IndexOfElement: int
        Coeffs: TColStd_Array2OfReal

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_Curve_SetElement(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_FEmTool_Curve_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _FEmTool.delete_FEmTool_Curve

# Register FEmTool_Curve in _FEmTool:
_FEmTool.FEmTool_Curve_swigregister(FEmTool_Curve)

class FEmTool_ElementaryCriterion(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def DependenceTable(self, *args) -> "opencascade::handle< TColStd_HArray2OfInteger >":
        r"""
        To know if two dimension are independent.

        Returns
        -------
        opencascade::handle<TColStd_HArray2OfInteger>

        """
        return _FEmTool.FEmTool_ElementaryCriterion_DependenceTable(self, *args)

    def Gradient(self, *args) -> "void":
        r"""
        To compute the coefficients in the dimension <dim> of the j(e)'s gradient where e is the current element.

        Parameters
        ----------
        Dim: int
        G: math_Vector

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_ElementaryCriterion_Gradient(self, *args)

    def Hessian(self, *args) -> "void":
        r"""
        To compute j(e) the coefficients of hessian matrix of j(e) wich are crossed derivatives in dimensions <dim1> and <dim2>. if dependencetable(dimension1,dimension2) is false.

        Parameters
        ----------
        Dim1: int
        Dim2: int
        H: math_Matrix

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_ElementaryCriterion_Hessian(self, *args)

    def Set(self, *args) -> "void":
        r"""
        Set the coefficient of the element (the curve).

        Parameters
        ----------
        Coeff: TColStd_HArray2OfReal

        Returns
        -------
        None
        Set the definition interval of the element.

        Parameters
        ----------
        FirstKnot: float
        LastKnot: float

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_ElementaryCriterion_Set(self, *args)

    def Value(self, *args) -> "Standard_Real":
        r"""
        To compute j(e) where e is the current element.

        Returns
        -------
        float

        """
        return _FEmTool.FEmTool_ElementaryCriterion_Value(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_FEmTool_ElementaryCriterion_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _FEmTool.delete_FEmTool_ElementaryCriterion

# Register FEmTool_ElementaryCriterion in _FEmTool:
_FEmTool.FEmTool_ElementaryCriterion_swigregister(FEmTool_ElementaryCriterion)

class FEmTool_ElementsOfRefMatrix(OCC.Core.math.math_FunctionSet):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        TheBase: PLib_Base
        DerOrder: int

        Returns
        -------
        None

        """
        _FEmTool.FEmTool_ElementsOfRefMatrix_swiginit(self, _FEmTool.new_FEmTool_ElementsOfRefMatrix(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _FEmTool.delete_FEmTool_ElementsOfRefMatrix

# Register FEmTool_ElementsOfRefMatrix in _FEmTool:
_FEmTool.FEmTool_ElementsOfRefMatrix_swigregister(FEmTool_ElementsOfRefMatrix)

class FEmTool_SparseMatrix(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def ChangeValue(self, *args) -> "Standard_Real &":
        r"""
        No available documentation.

        Parameters
        ----------
        I: int
        J: int

        Returns
        -------
        float

        """
        return _FEmTool.FEmTool_SparseMatrix_ChangeValue(self, *args)

    def ColNumber(self, *args) -> "Standard_Integer":
        r"""
        Returns the column range of the matrix.

        Returns
        -------
        int

        """
        return _FEmTool.FEmTool_SparseMatrix_ColNumber(self, *args)

    def Decompose(self, *args) -> "Standard_Boolean":
        r"""
        To make a factorization of <self>.

        Returns
        -------
        bool

        """
        return _FEmTool.FEmTool_SparseMatrix_Decompose(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Value: float

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_SparseMatrix_Init(self, *args)

    def Multiplied(self, *args) -> "void":
        r"""
        Returns the product of a sparsematrix by a vector. an exception is raised if the dimensions are different.

        Parameters
        ----------
        X: math_Vector
        MX: math_Vector

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_SparseMatrix_Multiplied(self, *args)

    def Prepare(self, *args) -> "Standard_Boolean":
        r"""
        Make preparation to iterative solve.

        Returns
        -------
        bool

        """
        return _FEmTool.FEmTool_SparseMatrix_Prepare(self, *args)

    def RowNumber(self, *args) -> "Standard_Integer":
        r"""
        Returns the row range of a matrix.

        Returns
        -------
        int

        """
        return _FEmTool.FEmTool_SparseMatrix_RowNumber(self, *args)

    def Solve(self, *args) -> "void":
        r"""
        Direct solve of ax = b.

        Parameters
        ----------
        B: math_Vector
        X: math_Vector

        Returns
        -------
        None
        Iterative solve of ax = b.

        Parameters
        ----------
        B: math_Vector
        Init: math_Vector
        X: math_Vector
        Residual: math_Vector
        Tolerance: float,optional
        	default value is 1.0e-8
        NbIterations: int,optional
        	default value is 50

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_SparseMatrix_Solve(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_FEmTool_SparseMatrix_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _FEmTool.delete_FEmTool_SparseMatrix

# Register FEmTool_SparseMatrix in _FEmTool:
_FEmTool.FEmTool_SparseMatrix_swigregister(FEmTool_SparseMatrix)

class FEmTool_LinearFlexion(FEmTool_ElementaryCriterion):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        WorkDegree: int
        ConstraintOrder: GeomAbs_Shape

        Returns
        -------
        None

        """
        _FEmTool.FEmTool_LinearFlexion_swiginit(self, _FEmTool.new_FEmTool_LinearFlexion(*args))


    @staticmethod
    def DownCast(t):
      return Handle_FEmTool_LinearFlexion_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _FEmTool.delete_FEmTool_LinearFlexion

# Register FEmTool_LinearFlexion in _FEmTool:
_FEmTool.FEmTool_LinearFlexion_swigregister(FEmTool_LinearFlexion)

class FEmTool_LinearJerk(FEmTool_ElementaryCriterion):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        WorkDegree: int
        ConstraintOrder: GeomAbs_Shape

        Returns
        -------
        None

        """
        _FEmTool.FEmTool_LinearJerk_swiginit(self, _FEmTool.new_FEmTool_LinearJerk(*args))


    @staticmethod
    def DownCast(t):
      return Handle_FEmTool_LinearJerk_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _FEmTool.delete_FEmTool_LinearJerk

# Register FEmTool_LinearJerk in _FEmTool:
_FEmTool.FEmTool_LinearJerk_swigregister(FEmTool_LinearJerk)

class FEmTool_LinearTension(FEmTool_ElementaryCriterion):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        WorkDegree: int
        ConstraintOrder: GeomAbs_Shape

        Returns
        -------
        None

        """
        _FEmTool.FEmTool_LinearTension_swiginit(self, _FEmTool.new_FEmTool_LinearTension(*args))


    @staticmethod
    def DownCast(t):
      return Handle_FEmTool_LinearTension_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _FEmTool.delete_FEmTool_LinearTension

# Register FEmTool_LinearTension in _FEmTool:
_FEmTool.FEmTool_LinearTension_swigregister(FEmTool_LinearTension)

class FEmTool_ProfileMatrix(FEmTool_SparseMatrix):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        FirstIndexes: TColStd_Array1OfInteger

        Returns
        -------
        None

        """
        _FEmTool.FEmTool_ProfileMatrix_swiginit(self, _FEmTool.new_FEmTool_ProfileMatrix(*args))

    def GetChangeValue(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "Standard_Real":
        r"""GetChangeValue(FEmTool_ProfileMatrix self, Standard_Integer const I, Standard_Integer const J) -> Standard_Real"""
        return _FEmTool.FEmTool_ProfileMatrix_GetChangeValue(self, I, J)

    def SetChangeValue(self, I: "Standard_Integer const", J: "Standard_Integer const", value: "Standard_Real") -> "void":
        r"""SetChangeValue(FEmTool_ProfileMatrix self, Standard_Integer const I, Standard_Integer const J, Standard_Real value)"""
        return _FEmTool.FEmTool_ProfileMatrix_SetChangeValue(self, I, J, value)

    def IsInProfile(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        i: int
        j: int

        Returns
        -------
        bool

        """
        return _FEmTool.FEmTool_ProfileMatrix_IsInProfile(self, *args)

    def OutM(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_ProfileMatrix_OutM(self, *args)

    def OutS(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_ProfileMatrix_OutS(self, *args)

    def Solve(self, *args) -> "void":
        r"""
        Direct solve of ax = b.

        Parameters
        ----------
        B: math_Vector
        X: math_Vector

        Returns
        -------
        None
        Iterative solve of ax = b.

        Parameters
        ----------
        B: math_Vector
        Init: math_Vector
        X: math_Vector
        Residual: math_Vector
        Tolerance: float,optional
        	default value is 1.0e-8
        NbIterations: int,optional
        	default value is 50

        Returns
        -------
        None

        """
        return _FEmTool.FEmTool_ProfileMatrix_Solve(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_FEmTool_ProfileMatrix_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _FEmTool.delete_FEmTool_ProfileMatrix

# Register FEmTool_ProfileMatrix in _FEmTool:
_FEmTool.FEmTool_ProfileMatrix_swigregister(FEmTool_ProfileMatrix)

class FEmTool_HAssemblyTable(FEmTool_AssemblyTable, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _FEmTool.FEmTool_HAssemblyTable_swiginit(self, _FEmTool.new_FEmTool_HAssemblyTable(*args))

    def Array2(self) -> "FEmTool_AssemblyTable const &":
        return _FEmTool.FEmTool_HAssemblyTable_Array2(self)

    def ChangeArray2(self) -> "FEmTool_AssemblyTable &":
        return _FEmTool.FEmTool_HAssemblyTable_ChangeArray2(self)


    @staticmethod
    def DownCast(t):
      return Handle_FEmTool_HAssemblyTable_DownCast(t)

    __swig_destroy__ = _FEmTool.delete_FEmTool_HAssemblyTable

# Register FEmTool_HAssemblyTable in _FEmTool:
_FEmTool.FEmTool_HAssemblyTable_swigregister(FEmTool_HAssemblyTable)





